@@ -1,5 +1,5 @@
 /* LiquidRescaling Library EXAMPLE program
- * Copyright (C) 2007-2009 Carlo Baldassi (the "Author") <carlobaldassi@gmail.com>.
+ * Copyright (C) 2007 Carlo Baldassi (the "Author") <carlobaldassi@gmail.com>.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,21 +46,17 @@
 	cerr << "Not enough memory, aborting." << endl; \
 	exit (1); \
 	break; \
-      case LQR_USRCANCEL: \
-	cerr << "Cancelled by user, aborting." << endl; \
-	exit (1); \
-	break; \
       default: \
 	break; \
     } \
-}G_STMT_END
+}G_STMT_END 
 
 /*** PARSE COMMAND LINE ***/
-LqrRetVal parse_command_line(int argc, char **argv);
+LqrRetVal parse_command_line (int argc, char **argv);
 void help(char *command);
 
 /*** RGB FILE I/O ***/
-guchar *rgb_buffer_from_image(pngwriter *png);
-LqrRetVal write_carver_to_image(LqrCarver *r, pngwriter *png);
+guchar *rgb_buffer_from_image (pngwriter * png);
+LqrRetVal write_carver_to_image (LqrCarver * r, pngwriter * png);
 
 #endif /* __LIQUIDRESCALE_BASIC_H__ */
